package
Version:
v1.1.2-0...-71dc7f8
Opens a new window with list of versions in this module.
Published: Jan 5, 2026
License: MIT
Opens a new window with license information.
Imports: 21
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command
func SetVersionInfo(version, commit, date, builtBy string)
SetVersionInfo sets the version information from main package
Source Files
¶
Click to show internal directories.
Click to hide internal directories.